@@ -1,6 +1,6 @@
 /*
 
-   BLIS    
+   BLIS
    An object-based framework for developing high-performance BLAS-like
    libraries.
 
@@ -172,7 +172,7 @@ void PASTEMAC(ch,varname) \
 		ctype_r*          p_edge_r = ( ctype_r* )p +        (i  )*rs_p; \
 		ctype_r*          p_edge_i = ( ctype_r* )p + is_p + (i  )*rs_p; \
 \
-		PASTEMAC(chr,setm) \
+		PASTEMAC2(chr,setm,BLIS_TAPI_EX_SUF) \
 		( \
 		  BLIS_NO_CONJUGATE, \
 		  0, \
@@ -182,9 +182,10 @@ void PASTEMAC(ch,varname) \
 		  n_edge, \
 		  zero_r, \
 		  p_edge_r, rs_p, cs_p, \
-		  cntx  \
+		  cntx, \
+		  NULL  \
 		); \
-		PASTEMAC(chr,setm) \
+		PASTEMAC2(chr,setm,BLIS_TAPI_EX_SUF) \
 		( \
 		  BLIS_NO_CONJUGATE, \
 		  0, \
@@ -194,7 +195,8 @@ void PASTEMAC(ch,varname) \
 		  n_edge, \
 		  zero_r, \
 		  p_edge_i, rs_p, cs_p, \
-		  cntx  \
+		  cntx, \
+		  NULL  \
 		); \
 	} \
 \
@@ -207,7 +209,7 @@ void PASTEMAC(ch,varname) \
 		ctype_r*          p_edge_r = ( ctype_r* )p +        (j  )*cs_p; \
 		ctype_r*          p_edge_i = ( ctype_r* )p + is_p + (j  )*cs_p; \
 \
-		PASTEMAC(chr,setm) \
+		PASTEMAC2(chr,setm,BLIS_TAPI_EX_SUF) \
 		( \
 		  BLIS_NO_CONJUGATE, \
 		  0, \
@@ -217,9 +219,10 @@ void PASTEMAC(ch,varname) \
 		  n_edge, \
 		  zero_r, \
 		  p_edge_r, rs_p, cs_p, \
-		  cntx  \
+		  cntx, \
+		  NULL  \
 		); \
-		PASTEMAC(chr,setm) \
+		PASTEMAC2(chr,setm,BLIS_TAPI_EX_SUF) \
 		( \
 		  BLIS_NO_CONJUGATE, \
 		  0, \
@@ -229,7 +232,8 @@ void PASTEMAC(ch,varname) \
 		  n_edge, \
 		  zero_r, \
 		  p_edge_i, rs_p, cs_p, \
-		  cntx  \
+		  cntx, \
+		  NULL  \
 		); \
 	} \
 \
@@ -256,7 +260,7 @@ void PASTEMAC(ch,varname) \
 			ctype_r*          p_br_r = ( ctype_r* )p +        (i  )*rs_p + (j  )*cs_p; \
 			ctype_r*          p_br_i = ( ctype_r* )p + is_p + (i  )*rs_p + (j  )*cs_p; \
 \
-			PASTEMAC(chr,setd) \
+			PASTEMAC2(chr,setd,BLIS_TAPI_EX_SUF) \
 			( \
 			  BLIS_NO_CONJUGATE, \
 			  0, \
@@ -264,9 +268,10 @@ void PASTEMAC(ch,varname) \
 			  n_br, \
 			  one_r, \
 			  p_br_r, rs_p, cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
-			PASTEMAC(chr,setd) \
+			PASTEMAC2(chr,setd,BLIS_TAPI_EX_SUF) \
 			( \
 			  BLIS_NO_CONJUGATE, \
 			  0, \
@@ -274,7 +279,8 @@ void PASTEMAC(ch,varname) \
 			  n_br, \
 			  zero_r, \
 			  p_br_i, rs_p, cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
 		} \
 	} \
@@ -337,10 +343,10 @@ void PASTEMAC(ch,varname) \
 		{ \
 			c = c + diagoffc * ( doff_t )cs_c + \
 			       -diagoffc * ( doff_t )rs_c;  \
-			bli_swap_incs( incc, ldc ); \
+			bli_swap_incs( &incc, &ldc ); \
 \
 			if ( bli_is_hermitian( strucc ) ) \
-				bli_toggle_conj( conjc ); \
+				bli_toggle_conj( &conjc ); \
 		} \
 \
 		/* Pack the full panel. */ \
@@ -410,7 +416,7 @@ void PASTEMAC(ch,varname) \
 			conjc12    = conjc; \
 \
 			if ( bli_is_hermitian( strucc ) ) \
-				bli_toggle_conj( conjc12 ); \
+				bli_toggle_conj( &conjc12 ); \
 		} \
 		else /* if ( ( row_stored && bli_is_lower( uploc ) ) || \
 		             ( col_stored && bli_is_upper( uploc ) ) ) */ \
@@ -436,7 +442,7 @@ void PASTEMAC(ch,varname) \
 			conjc12    = conjc; \
 \
 			if ( bli_is_hermitian( strucc ) ) \
-				bli_toggle_conj( conjc10 ); \
+				bli_toggle_conj( &conjc10 ); \
 		} \
 \
 		/* Pack to p10. For upper storage, this includes the unstored
@@ -447,8 +453,8 @@ void PASTEMAC(ch,varname) \
 		  p10_dim, \
 		  p10_len, \
 		  kappa, \
-		  c10, incc10, ldc10, \
-		  p10, is_p,   ldp, \
+		            c10, incc10, ldc10, \
+		  ( ctype* )p10, is_p,   ldp, \
 		  cntx  \
 		); \
 \
@@ -460,8 +466,8 @@ void PASTEMAC(ch,varname) \
 		  p12_dim, \
 		  p12_len, \
 		  kappa, \
-		  c12, incc12, ldc12, \
-		  p12, is_p,   ldp, \
+		            c12, incc12, ldc12, \
+		  ( ctype* )p12, is_p,   ldp, \
 		  cntx  \
 		); \
 \
@@ -484,7 +490,7 @@ void PASTEMAC(ch,varname) \
 			ctype_r  kappa_i = PASTEMAC(ch,imag)( *kappa ); \
 \
 			/* Copy the real part of the stored triangle of c11 to p11_r. */ \
-			PASTEMAC(chr,scal2m) \
+			PASTEMAC2(chr,scal2m,BLIS_TAPI_EX_SUF) \
 			( \
 			  0, \
 			  BLIS_NONUNIT_DIAG, \
@@ -495,12 +501,13 @@ void PASTEMAC(ch,varname) \
 			  alpha_r, \
 			  c11_r, rs_c11, cs_c11, \
 			  p11_r, rs_p,   cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
 \
 			/* Copy the imaginary part of the stored triangle of c11 to p11_i,
 			   scaling by -1 if conjugation on c was requested. */ \
-			PASTEMAC(chr,scal2m) \
+			PASTEMAC2(chr,scal2m,BLIS_TAPI_EX_SUF) \
 			( \
 			  0, \
 			  BLIS_NONUNIT_DIAG, \
@@ -511,7 +518,8 @@ void PASTEMAC(ch,varname) \
 			  alpha_i, \
 			  c11_i, rs_c11, cs_c11, \
 			  p11_i, rs_p,   cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
 \
 			/* If source matrix c is Hermitian, we have to zero out the
@@ -626,7 +634,7 @@ void PASTEMAC(ch,varname) \
 			ctype_r kappa_r = PASTEMAC(ch,real)( *kappa ); \
 			ctype_r kappa_i = PASTEMAC(ch,imag)( *kappa ); \
 \
-			PASTEMAC(chr,setd) \
+			PASTEMAC2(chr,setd,BLIS_TAPI_EX_SUF) \
 			( \
 			  BLIS_NO_CONJUGATE, \
 			  diagoffp, \
@@ -634,9 +642,10 @@ void PASTEMAC(ch,varname) \
 			  n_panel, \
 			  &kappa_r, \
 			  p_r, rs_p, cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
-			PASTEMAC(chr,setd) \
+			PASTEMAC2(chr,setd,BLIS_TAPI_EX_SUF) \
 			( \
 			  BLIS_NO_CONJUGATE, \
 			  diagoffp, \
@@ -644,7 +653,8 @@ void PASTEMAC(ch,varname) \
 			  n_panel, \
 			  &kappa_i, \
 			  p_i, rs_p, cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
 		} \
 \
@@ -676,10 +686,10 @@ void PASTEMAC(ch,varname) \
 			ctype_r* restrict zero_r = PASTEMAC(chr,0); \
 			uplo_t            uplop  = uploc; \
 \
-			bli_toggle_uplo( uplop ); \
-			bli_shift_diag_offset_to_shrink_uplo( uplop, diagoffp ); \
+			bli_toggle_uplo( &uplop ); \
+			bli_shift_diag_offset_to_shrink_uplo( uplop, &diagoffp ); \
 \
-			PASTEMAC(chr,setm) \
+			PASTEMAC2(chr,setm,BLIS_TAPI_EX_SUF) \
 			( \
 			  BLIS_NO_CONJUGATE, \
 			  diagoffp, \
@@ -689,9 +699,10 @@ void PASTEMAC(ch,varname) \
 			  n_panel, \
 			  zero_r, \
 			  p_r, rs_p, cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
-			PASTEMAC(chr,setm) \
+			PASTEMAC2(chr,setm,BLIS_TAPI_EX_SUF) \
 			( \
 			  BLIS_NO_CONJUGATE, \
 			  diagoffp, \
@@ -701,7 +712,8 @@ void PASTEMAC(ch,varname) \
 			  n_panel, \
 			  zero_r, \
 			  p_i, rs_p, cs_p, \
-			  cntx  \
+			  cntx, \
+			  NULL  \
 			); \
 		} \
 	} \
