@@ -5,6 +5,7 @@
    libraries.
 
    Copyright (C) 2014, The University of Texas at Austin
+   Copyright (C) 2018, Advanced Micro Devices, Inc.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are
@@ -53,7 +54,16 @@ cntl_t* bli_trsm_l_cntl_create
        pack_t schema_b
      )
 {
-	void* macro_kernel_p = bli_trsm_xx_ker_var2;
+	void* macro_kernel_p;
+	void* packa_fp;
+	void* packb_fp;
+
+	// Use the function pointer to the macrokernels that use slab
+	// assignment of micropanels to threads in the jr and ir loops.
+	macro_kernel_p = bli_trsm_xx_ker_var2;
+
+	packa_fp = bli_packm_blk_var1;
+	packb_fp = bli_packm_blk_var1;
 
 	const opid_t family = BLIS_TRSM;
 
@@ -78,7 +88,7 @@ cntl_t* bli_trsm_l_cntl_create
 	cntl_t* trsm_cntl_packa = bli_packm_cntl_create_node
 	(
 	  bli_trsm_packa,
-	  bli_packm_blk_var1,
+	  packa_fp,
 	  BLIS_MR,
 	  BLIS_MR,
 	  TRUE,    // do NOT invert diagonal
@@ -102,7 +112,7 @@ cntl_t* bli_trsm_l_cntl_create
 	cntl_t* trsm_cntl_packb = bli_packm_cntl_create_node
 	(
 	  bli_trsm_packb,
-	  bli_packm_blk_var1,
+	  packb_fp,
 	  BLIS_MR,
 	  BLIS_NR,
 	  FALSE,   // do NOT invert diagonal
@@ -140,8 +150,12 @@ cntl_t* bli_trsm_r_cntl_create
        pack_t schema_b
      )
 {
+	// NOTE: trsm macrokernels are presently disabled for right-side execution.
 	void* macro_kernel_p = bli_trsm_xx_ker_var2;
 
+	void* packa_fp = bli_packm_blk_var1;
+	void* packb_fp = bli_packm_blk_var1;
+
 	const opid_t family = BLIS_TRSM;
 
 	// Create two nodes for the macro-kernel.
@@ -165,7 +179,7 @@ cntl_t* bli_trsm_r_cntl_create
 	cntl_t* trsm_cntl_packa = bli_packm_cntl_create_node
 	(
 	  bli_trsm_packa,
-	  bli_packm_blk_var1,
+	  packa_fp,
 	  BLIS_NR,
 	  BLIS_MR,
 	  FALSE,   // do NOT invert diagonal
@@ -189,7 +203,7 @@ cntl_t* bli_trsm_r_cntl_create
 	cntl_t* trsm_cntl_packb = bli_packm_cntl_create_node
 	(
 	  bli_trsm_packb,
-	  bli_packm_blk_var1,
+	  packb_fp,
 	  BLIS_MR,
 	  BLIS_MR,
 	  TRUE,    // do NOT invert diagonal
