@@ -62,6 +62,17 @@
 
 // -- General-purpose integers --
 
+// If BLAS integers are 64 bits, mandate that BLIS integers also be 64 bits.
+// NOTE: This cpp guard will only meaningfully change BLIS's behavior on
+// systems where the BLIS integer size would have been automatically selected
+// to be 32 bits, since explicit selection of 32 bits is prohibited at
+// configure-time (and explicit or automatic selection of 64 bits is fine
+// and would have had the same result).
+#if BLIS_BLAS_INT_SIZE == 64
+  #undef  BLIS_INT_TYPE_SIZE
+  #define BLIS_INT_TYPE_SIZE 64
+#endif
+
 // Define integer types depending on what size integer was requested.
 #if   BLIS_INT_TYPE_SIZE == 32
 typedef           int32_t  gint_t;
@@ -257,6 +268,10 @@ typedef dcomplex  f77_dcomplex;
            - 1 == Hermitian
            - 2 == symmetric
            - 3 == triangular
+  31 ~ 29  Execution numerical datatype
+           - 29: domain    (0 == real, 1 == complex)
+           - 30: precision (0 == single, 1 == double)
+           - 31: used to encode integer, constant types
 */
 
 #define BLIS_DATATYPE_SHIFT                0
@@ -286,6 +301,9 @@ typedef dcomplex  f77_dcomplex;
 #define BLIS_PACK_REV_IF_LOWER_SHIFT       24
 #define BLIS_PACK_BUFFER_SHIFT             25
 #define BLIS_STRUC_SHIFT                   27
+#define BLIS_COMP_DT_SHIFT                 29
+#define   BLIS_COMP_DOMAIN_SHIFT           29
+#define   BLIS_COMP_PREC_SHIFT             30
 
 //
 // -- BLIS info bit field masks ------------------------------------------------
@@ -318,6 +336,9 @@ typedef dcomplex  f77_dcomplex;
 #define BLIS_PACK_REV_IF_LOWER_BIT         ( 0x1  << BLIS_PACK_REV_IF_LOWER_SHIFT )
 #define BLIS_PACK_BUFFER_BITS              ( 0x3  << BLIS_PACK_BUFFER_SHIFT )
 #define BLIS_STRUC_BITS                    ( 0x3  << BLIS_STRUC_SHIFT )
+#define BLIS_COMP_DT_BITS                  ( 0x7  << BLIS_COMP_DT_SHIFT )
+#define   BLIS_COMP_DOMAIN_BIT             ( 0x1  << BLIS_COMP_DOMAIN_SHIFT )
+#define   BLIS_COMP_PREC_BIT               ( 0x1  << BLIS_COMP_PREC_SHIFT )
 
 
 //
@@ -603,13 +624,15 @@ typedef enum
 
 typedef enum
 {
-	BLIS_3MH = 0,
+	BLIS_3MH       = 0,
 	BLIS_3M1,
 	BLIS_4MH,
 	BLIS_4M1B,
 	BLIS_4M1A,
 	BLIS_1M,
-	BLIS_NAT
+	BLIS_NAT,
+	BLIS_IND_FIRST = 0,
+	BLIS_IND_LAST  = BLIS_NAT
 } ind_t;
 
 #define BLIS_NUM_IND_METHODS (BLIS_NAT+1)
@@ -903,16 +926,18 @@ typedef struct
 
 // -- Memory broker object type --
 
-#include "bli_pthread_wrap.h"
+// These headers must be included here (or earlier) because definitions they
+// provide are needed in the membrk_t struct.
+#include "bli_pthread.h"
 #include "bli_malloc.h"
 
 typedef struct membrk_s
 {
-	pool_t          pools[3];
-	pthread_mutex_t mutex;
+	pool_t              pools[3];
+	bli_pthread_mutex_t mutex;
 
-	malloc_ft       malloc_fp;
-	free_ft         free_fp;
+	malloc_ft           malloc_fp;
+	free_ft             free_fp;
 } membrk_t;
 
 
@@ -1003,7 +1028,7 @@ typedef struct
 	inc_t  is_b;
 
 	// The type to convert to on output.
-	num_t  dt_on_output;
+	//num_t  dt_on_output;
 
 } auxinfo_t;
 
