@@ -61,7 +61,7 @@ void bli_thread_finalize( void )
 
 // -----------------------------------------------------------------------------
 
-void bli_thread_get_range_sub
+void bli_thread_range_sub
      (
        thrinfo_t* thread,
        dim_t      n,
@@ -72,6 +72,9 @@ void bli_thread_get_range_sub
      )
 {
 	dim_t      n_way      = bli_thread_n_way( thread );
+
+	if ( n_way == 1 ) { *start = 0; *end = n; return; }
+
 	dim_t      work_id    = bli_thread_work_id( thread );
 
 	dim_t      all_start  = 0;
@@ -202,7 +205,7 @@ void bli_thread_get_range_sub
 	}
 }
 
-siz_t bli_thread_get_range_l2r
+siz_t bli_thread_range_l2r
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -216,13 +219,13 @@ siz_t bli_thread_get_range_l2r
 	dim_t n  = bli_obj_width_after_trans( a );
 	dim_t bf = bli_blksz_get_def( dt, bmult );
 
-	bli_thread_get_range_sub( thr, n, bf,
-	                          FALSE, start, end );
+	bli_thread_range_sub( thr, n, bf,
+	                      FALSE, start, end );
 
 	return m * ( *end - *start );
 }
 
-siz_t bli_thread_get_range_r2l
+siz_t bli_thread_range_r2l
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -236,13 +239,13 @@ siz_t bli_thread_get_range_r2l
 	dim_t n  = bli_obj_width_after_trans( a );
 	dim_t bf = bli_blksz_get_def( dt, bmult );
 
-	bli_thread_get_range_sub( thr, n, bf,
-	                          TRUE, start, end );
+	bli_thread_range_sub( thr, n, bf,
+	                      TRUE, start, end );
 
 	return m * ( *end - *start );
 }
 
-siz_t bli_thread_get_range_t2b
+siz_t bli_thread_range_t2b
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -256,13 +259,13 @@ siz_t bli_thread_get_range_t2b
 	dim_t n  = bli_obj_width_after_trans( a );
 	dim_t bf = bli_blksz_get_def( dt, bmult );
 
-	bli_thread_get_range_sub( thr, m, bf,
-	                          FALSE, start, end );
+	bli_thread_range_sub( thr, m, bf,
+	                      FALSE, start, end );
 
 	return n * ( *end - *start );
 }
 
-siz_t bli_thread_get_range_b2t
+siz_t bli_thread_range_b2t
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -276,15 +279,15 @@ siz_t bli_thread_get_range_b2t
 	dim_t n  = bli_obj_width_after_trans( a );
 	dim_t bf = bli_blksz_get_def( dt, bmult );
 
-	bli_thread_get_range_sub( thr, m, bf,
-	                          TRUE, start, end );
+	bli_thread_range_sub( thr, m, bf,
+	                      TRUE, start, end );
 
 	return n * ( *end - *start );
 }
 
 // -----------------------------------------------------------------------------
 
-dim_t bli_thread_get_range_width_l
+dim_t bli_thread_range_width_l
      (
        doff_t diagoff_j,
        dim_t  m,
@@ -495,17 +498,17 @@ siz_t bli_find_area_trap_l
 
 // -----------------------------------------------------------------------------
 
-siz_t bli_thread_get_range_weighted_sub
+siz_t bli_thread_range_weighted_sub
      (
-       thrinfo_t* thread,
-       doff_t     diagoff,
-       uplo_t     uplo,
-       dim_t      m,
-       dim_t      n,
-       dim_t      bf,
-       bool_t     handle_edge_low,
-       dim_t*     j_start_thr,
-       dim_t*     j_end_thr
+       thrinfo_t* restrict thread,
+       doff_t              diagoff,
+       uplo_t              uplo,
+       dim_t               m,
+       dim_t               n,
+       dim_t               bf,
+       bool_t              handle_edge_low,
+       dim_t*     restrict j_start_thr,
+       dim_t*     restrict j_end_thr
      )
 {
 	dim_t      n_way   = bli_thread_n_way( thread );
@@ -570,7 +573,7 @@ siz_t bli_thread_get_range_weighted_sub
 			// Compute the width of the jth subpartition, taking the
 			// current diagonal offset into account, if needed.
 			width_j =
-			bli_thread_get_range_width_l
+			bli_thread_range_width_l
 			(
 			  diagoff_j, m, n_left,
 			  j, n_way,
@@ -614,7 +617,7 @@ siz_t bli_thread_get_range_weighted_sub
 		bli_toggle_bool( &handle_edge_low );
 
 		// Compute the appropriate range for the rotated trapezoid.
-		area = bli_thread_get_range_weighted_sub
+		area = bli_thread_range_weighted_sub
 		(
 		  thread, diagoff, uplo, m, n, bf,
 		  handle_edge_low,
@@ -632,7 +635,7 @@ siz_t bli_thread_get_range_weighted_sub
 	return area;
 }
 
-siz_t bli_thread_get_range_mdim
+siz_t bli_thread_range_mdim
      (
        dir_t      direct,
        thrinfo_t* thr,
@@ -678,20 +681,20 @@ siz_t bli_thread_get_range_mdim
 	if ( use_weighted )
 	{
 		if ( direct == BLIS_FWD )
-			return bli_thread_get_range_weighted_t2b( thr, x, bmult, start, end );
+			return bli_thread_range_weighted_t2b( thr, x, bmult, start, end );
 		else
-			return bli_thread_get_range_weighted_b2t( thr, x, bmult, start, end );
+			return bli_thread_range_weighted_b2t( thr, x, bmult, start, end );
 	}
 	else
 	{
 		if ( direct == BLIS_FWD )
-			return bli_thread_get_range_t2b( thr, x, bmult, start, end );
+			return bli_thread_range_t2b( thr, x, bmult, start, end );
 		else
-			return bli_thread_get_range_b2t( thr, x, bmult, start, end );
+			return bli_thread_range_b2t( thr, x, bmult, start, end );
 	}
 }
 
-siz_t bli_thread_get_range_ndim
+siz_t bli_thread_range_ndim
      (
        dir_t      direct,
        thrinfo_t* thr,
@@ -737,20 +740,20 @@ siz_t bli_thread_get_range_ndim
 	if ( use_weighted )
 	{
 		if ( direct == BLIS_FWD )
-			return bli_thread_get_range_weighted_l2r( thr, x, bmult, start, end );
+			return bli_thread_range_weighted_l2r( thr, x, bmult, start, end );
 		else
-			return bli_thread_get_range_weighted_r2l( thr, x, bmult, start, end );
+			return bli_thread_range_weighted_r2l( thr, x, bmult, start, end );
 	}
 	else
 	{
 		if ( direct == BLIS_FWD )
-			return bli_thread_get_range_l2r( thr, x, bmult, start, end );
+			return bli_thread_range_l2r( thr, x, bmult, start, end );
 		else
-			return bli_thread_get_range_r2l( thr, x, bmult, start, end );
+			return bli_thread_range_r2l( thr, x, bmult, start, end );
 	}
 }
 
-siz_t bli_thread_get_range_weighted_l2r
+siz_t bli_thread_range_weighted_l2r
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -782,7 +785,7 @@ siz_t bli_thread_get_range_weighted_l2r
 		}
 
 		area =
-		bli_thread_get_range_weighted_sub
+		bli_thread_range_weighted_sub
 		(
 		  thr, diagoff, uplo, m, n, bf,
 		  FALSE, start, end
@@ -790,7 +793,7 @@ siz_t bli_thread_get_range_weighted_l2r
 	}
 	else // if dense or zeros
 	{
-		area = bli_thread_get_range_l2r
+		area = bli_thread_range_l2r
 		(
 		  thr, a, bmult,
 		  start, end
@@ -800,7 +803,7 @@ siz_t bli_thread_get_range_weighted_l2r
 	return area;
 }
 
-siz_t bli_thread_get_range_weighted_r2l
+siz_t bli_thread_range_weighted_r2l
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -834,7 +837,7 @@ siz_t bli_thread_get_range_weighted_r2l
 		bli_rotate180_trapezoid( &diagoff, &uplo, &m, &n );
 
 		area =
-		bli_thread_get_range_weighted_sub
+		bli_thread_range_weighted_sub
 		(
 		  thr, diagoff, uplo, m, n, bf,
 		  TRUE, start, end
@@ -842,7 +845,7 @@ siz_t bli_thread_get_range_weighted_r2l
 	}
 	else // if dense or zeros
 	{
-		area = bli_thread_get_range_r2l
+		area = bli_thread_range_r2l
 		(
 		  thr, a, bmult,
 		  start, end
@@ -852,7 +855,7 @@ siz_t bli_thread_get_range_weighted_r2l
 	return area;
 }
 
-siz_t bli_thread_get_range_weighted_t2b
+siz_t bli_thread_range_weighted_t2b
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -886,7 +889,7 @@ siz_t bli_thread_get_range_weighted_t2b
 		bli_reflect_about_diag( &diagoff, &uplo, &m, &n );
 
 		area =
-		bli_thread_get_range_weighted_sub
+		bli_thread_range_weighted_sub
 		(
 		  thr, diagoff, uplo, m, n, bf,
 		  FALSE, start, end
@@ -894,7 +897,7 @@ siz_t bli_thread_get_range_weighted_t2b
 	}
 	else // if dense or zeros
 	{
-		area = bli_thread_get_range_t2b
+		area = bli_thread_range_t2b
 		(
 		  thr, a, bmult,
 		  start, end
@@ -904,7 +907,7 @@ siz_t bli_thread_get_range_weighted_t2b
 	return area;
 }
 
-siz_t bli_thread_get_range_weighted_b2t
+siz_t bli_thread_range_weighted_b2t
      (
        thrinfo_t* thr,
        obj_t*     a,
@@ -939,7 +942,7 @@ siz_t bli_thread_get_range_weighted_b2t
 
 		bli_rotate180_trapezoid( &diagoff, &uplo, &m, &n );
 
-		area = bli_thread_get_range_weighted_sub
+		area = bli_thread_range_weighted_sub
 		(
 		  thr, diagoff, uplo, m, n, bf,
 		  TRUE, start, end
@@ -947,7 +950,7 @@ siz_t bli_thread_get_range_weighted_b2t
 	}
 	else // if dense or zeros
 	{
-		area = bli_thread_get_range_b2t
+		area = bli_thread_range_b2t
 		(
 		  thr, a, bmult,
 		  start, end
@@ -1296,28 +1299,28 @@ dim_t bli_thread_get_num_threads( void )
 // ----------------------------------------------------------------------------
 
 // A mutex to allow synchronous access to global_rntm.
-static pthread_mutex_t global_rntm_mutex = PTHREAD_MUTEX_INITIALIZER;
+static bli_pthread_mutex_t global_rntm_mutex = BLIS_PTHREAD_MUTEX_INITIALIZER;
 
 void bli_thread_set_ways( dim_t jc, dim_t pc, dim_t ic, dim_t jr, dim_t ir )
 {
 	// Acquire the mutex protecting global_rntm.
-	pthread_mutex_lock( &global_rntm_mutex );
+	bli_pthread_mutex_lock( &global_rntm_mutex );
 
 	bli_rntm_set_ways_only( jc, pc, ic, jr, ir, &global_rntm );
 
 	// Release the mutex protecting global_rntm.
-	pthread_mutex_unlock( &global_rntm_mutex );
+	bli_pthread_mutex_unlock( &global_rntm_mutex );
 }
 
 void bli_thread_set_num_threads( dim_t n_threads )
 {
 	// Acquire the mutex protecting global_rntm.
-	pthread_mutex_lock( &global_rntm_mutex );
+	bli_pthread_mutex_lock( &global_rntm_mutex );
 
 	bli_rntm_set_num_threads_only( n_threads, &global_rntm );
 
 	// Release the mutex protecting global_rntm.
-	pthread_mutex_unlock( &global_rntm_mutex );
+	bli_pthread_mutex_unlock( &global_rntm_mutex );
 }
 
 // ----------------------------------------------------------------------------
@@ -1325,12 +1328,12 @@ void bli_thread_set_num_threads( dim_t n_threads )
 void bli_thread_init_rntm( rntm_t* rntm )
 {
 	// Acquire the mutex protecting global_rntm.
-	pthread_mutex_lock( &global_rntm_mutex );
+	bli_pthread_mutex_lock( &global_rntm_mutex );
 
 	*rntm = global_rntm;
 
 	// Release the mutex protecting global_rntm.
-	pthread_mutex_unlock( &global_rntm_mutex );
+	bli_pthread_mutex_unlock( &global_rntm_mutex );
 }
 
 // ----------------------------------------------------------------------------
